==> archibald-7.x-2.1.tar.gz: archibald/includes/languages/it.php <==
<?php

/**
 * @file
 * List  ISO 639-1 language codes and its italien names
 */
$languages = array(
  'aa' => 'Afar',
  'ab' => 'Abkhazian',
  'af' => 'Afrikaans',
  'am' => 'Amarico',
  'ar' => 'Arabo',
  'as' => 'Assamese',
  'ay' => 'Aymara',
  'az' => 'Azerbaigiano',
  'ba' => 'Baschiro',
  'be' => 'Bielorusso',
  'bg' => 'Bulgaro',
  'bh' => 'Bihari',
  'bi' => 'Bislama',
  'bn' => 'Bengalese',
  'bo' => 'Tibetano',
  'br' => 'Bretone',
  'ca' => 'Catalano',
  'co' => 'Corso',
  'cs' => 'Ceco',
  'cy' => 'Gallese',
  'da' => 'Danese',
  'de' => 'Tedesco',
  'dz' => 'Dzongkha',
  'el' => 'Greco',
  'en' => 'Inglese',
  'eo' => 'Esperanto',
  'es' => 'Spagnolo',
  'et' => 'Estone',
  'eu' => 'Basco',
  'fa' => 'Persiano',
  'fi' => 'Finlandese',
  'fj' => 'Figiano',
  'fo' => 'Faroese',
  'fr' => 'Francese',
  'fy' => 'Frisone',
  'ga' => 'Irlandese',
  'gd' => 'Gaelico scozzese',
  'gl' => 'Galiziano',
  'gn' => 'Guarana',
  'gu' => 'Gujarati',
  'ha' => 'Haussa',
  'he' => 'Ebraico',
  'hi' => 'Hindi',
  'hr' => 'Croato',
  'hu' => 'Ungherese',
  'hy' => 'Armeno',
  'ia' => 'Interlingua',
  'id' => 'Indonesiano',
  'ie' => 'Interlingue',
  'ik' => 'Inupiak',
  'is' => 'Islandese',
  'it' => 'Italiano',
  'iu' => 'Inuktitut',
  'iw' => '',
  'in' => '',
  'ja' => 'Giapponese',
  'jw' => '',
  'ji' => '',
  'ka' => 'Georgiano',
  'kk' => 'Kazako',
  'kl' => 'Kalaallisut',
  'km' => 'Khmer',
  'kn' => 'Kannada',
  'ko' => 'Coreano',
  'ks' => 'Kashmiri',
  'ku' => 'Curdo',
  'ky' => 'Kirghiso',
  'la' => 'Latino',
  'ln' => 'Lingala',
  'lo' => 'Lao',
  'lt' => 'Lituano',
  'lv' => 'Lettone',
  'mg' => 'Malgascio',
  'mi' => 'Maori',
  'mk' => 'Macedone',
  'ml' => 'Malayalam',
  'mn' => 'Mongolo',
  'mo' => 'Moldavo',
  'mr' => 'Marathi',
  'ms' => 'Malese',
  'mt' => 'Maltese',
  'my' => 'Birmano',
  'na' => 'Nauru',
  'ne' => 'Nepalese',
  'nl' => 'Olandese',
  'no' => 'Norvegese',
  'oc' => 'Occitano (post 1500); provenzale',
  'om' => 'Oromo',
  'or' => 'Oriya',
  'pa' => 'Punjabi',
  'pl' => 'Polacco',
  'ps' => 'Pashto',
  'pt' => 'Portoghese',
  'qu' => 'Quechua',
  'rm' => 'Lingua rhaeto-romance',
  'rm2907' => 'Rhaeto-Romance Puter',
  'rm2908' => 'Rhaeto-Romance Rumantsch grischun',
  'rm16068' => 'Rhaeto-Romance Surmiran',
  'rm16069' => 'Rhaeto-Romance Sursilvan',
  'rm13312' => 'Rhaeto-Romance Sutsilvan',
  'rm2906' => 'Rhaeto-Romance Vallader',
  'rn' => 'Rundi',
  'ro' => 'Rumeno',
  'ru' => 'Russo',
  'rw' => 'Kinyarwanda',
  'sa' => 'Sanscrito',
  'sd' => 'Sindhi',
  'sg' => 'Sango',
  'sh' => 'Serbo-croato',
  'si' => 'Singalese',
  'sk' => 'Slovacco',
  'sl' => 'Sloveno',
  'sm' => 'Samoano',
  'sn' => 'Shona',
  'so' => 'Somalo',
  'sq' => 'Albanese',
  'sr' => 'Serbo',
  'ss' => 'Swati',
  'st' => 'Sotho del sud',
  'su' => 'Sundanese',
  'sv' => 'Svedese',
  'sw' => 'Swahili',
  'ta' => 'Tamil',
  'te' => 'Telugu',
  'tg' => 'Tagicco',
  'th' => 'Thai',
  'ti' => 'Tigrinya',
  'tk' => 'Turcomanno',
  'tl' => 'Tagalog',
  'tn' => 'Tswana',
  'to' => 'Tonga (Isole Tonga)',
  'tr' => 'Turco',
  'ts' => 'Tsonga',
  'tt' => 'Tatarico',
  'tw' => 'Ci',
  'ug' => 'Uigurico',
  'uk' => 'Ucraino',
  'ur' => 'Urdu',
  'uz' => 'Usbeco',
  'vi' => 'Vietnamita',
  'vo' => 'Volapük',
  'wo' => 'Volof',
  'xh' => 'Xosa',
  'yi' => 'Yiddish',
  'yo' => 'Yoruba',
  'za' => 'Zhuang',
  'zh' => 'Cinese',
  'zu' => 'Zulu',
);

==> archibald-7.x-2.9.tar.gz: archibald/includes/languages/it.php <==
<?php

/**
 * @file
 * List  ISO 639-1 language codes and its italien names
 */
$languages = array(
  'aa' => 'Afar',
  'ab' => 'Abkhazian',
  'af' => 'Afrikaans',
  'am' => 'Amarico',
  'ar' => 'Arabo',
  'as' => 'Assamese',
  'ay' => 'Aymara',
  'az' => 'Azerbaigiano',
  'ba' => 'Baschiro',
  'be' => 'Bielorusso',
  'bg' => 'Bulgaro',
  'bh' => 'Bihari',
  'bi' => 'Bislama',
  'bn' => 'Bengalese',
  'bo' => 'Tibetano',
  'br' => 'Bretone',
  'ca' => 'Catalano',
  'co' => 'Corso',
  'cs' => 'Ceco',
  'cy' => 'Gallese',
  'da' => 'Danese',
  'de' => 'Tedesco',
  'dz' => 'Dzongkha',
  'el' => 'Greco',
  'en' => 'Inglese',
  'eo' => 'Esperanto',
  'es' => 'Spagnolo',
  'et' => 'Estone',
  'eu' => 'Basco',
  'fa' => 'Persiano',
  'fi' => 'Finlandese',
  'fj' => 'Figiano',
  'fo' => 'Faroese',
  'fr' => 'Francese',
  'fy' => 'Frisone',
  'ga' => 'Irlandese',
  'gd' => 'Gaelico scozzese',
  'gl' => 'Galiziano',
  'gn' => 'Guarana',
  'gu' => 'Gujarati',
  'ha' => 'Haussa',
  'he' => 'Ebraico',
  'hi' => 'Hindi',
  'hr' => 'Croato',
  'hu' => 'Ungherese',
  'hy' => 'Armeno',
  'ia' => 'Interlingua',
  'id' => 'Indonesiano',
  'ie' => 'Interlingue',
  'ik' => 'Inupiak',
  'is' => 'Islandese',
  'it' => 'Italiano',
  'iu' => 'Inuktitut',
  'iw' => '',
  'in' => '',
  'ja' => 'Giapponese',
  'jw' => '',
  'ji' => '',
  'ka' => 'Georgiano',
  'kk' => 'Kazako',
  'kl' => 'Kalaallisut',
  'km' => 'Khmer',
  'kn' => 'Kannada',
  'ko' => 'Coreano',
  'ks' => 'Kashmiri',
  'ku' => 'Curdo',
  'ky' => 'Kirghiso',
  'la' => 'Latino',
  'ln' => 'Lingala',
  'lo' => 'Lao',
  'lt' => 'Lituano',
  'lv' => 'Lettone',
  'mg' => 'Malgascio',
  'mi' => 'Maori',
  'mk' => 'Macedone',
  'ml' => 'Malayalam',
  'mn' => 'Mongolo',
  'mo' => 'Moldavo',
  'mr' => 'Marathi',
  'ms' => 'Malese',
  'mt' => 'Maltese',
  'my' => 'Birmano',
  'na' => 'Nauru',
  'ne' => 'Nepalese',
  'nl' => 'Olandese',
  'no' => 'Norvegese',
  'oc' => 'Occitano (post 1500); provenzale',
  'om' => 'Oromo',
  'or' => 'Oriya',
  'pa' => 'Punjabi',
  'pl' => 'Polacco',
  'ps' => 'Pashto',
  'pt' => 'Portoghese',
  'qu' => 'Quechua',
  'rm' => 'Romancio',
  'rm2907' => 'Puter',
  'rm2908' => 'Rumantsch grischun',
  'rm16068' => 'Surmiran',
  'rm16069' => 'Sursilvan',
  'rm13312' => 'Sutsilvan',
  'rm2906' => 'Vallader',
  'rn' => 'Rundi',
  'ro' => 'Rumeno',
  'ru' => 'Russo',
  'rw' => 'Kinyarwanda',
  'sa' => 'Sanscrito',
  'sd' => 'Sindhi',
  'sg' => 'Sango',
  'sh' => 'Serbo-croato',
  'si' => 'Singalese',
  'sk' => 'Slovacco',
  'sl' => 'Sloveno',
  'sm' => 'Samoano',
  'sn' => 'Shona',
  'so' => 'Somalo',
  'sq' => 'Albanese',
  'sr' => 'Serbo',
  'ss' => 'Swati',
  'st' => 'Sotho del sud',
  'su' => 'Sundanese',
  'sv' => 'Svedese',
  'sw' => 'Swahili',
  'ta' => 'Tamil',
  'te' => 'Telugu',
  'tg' => 'Tagicco',
  'th' => 'Thai',
  'ti' => 'Tigrinya',
  'tk' => 'Turcomanno',
  'tl' => 'Tagalog',
  'tn' => 'Tswana',
  'to' => 'Tonga (Isole Tonga)',
  'tr' => 'Turco',
  'ts' => 'Tsonga',
  'tt' => 'Tatarico',
  'tw' => 'Ci',
  'ug' => 'Uigurico',
  'uk' => 'Ucraino',
  'ur' => 'Urdu',
  'uz' => 'Usbeco',
  'vi' => 'Vietnamita',
  'vo' => 'Volapük',
  'wo' => 'Volof',
  'xh' => 'Xosa',
  'yi' => 'Yiddish',
  'yo' => 'Yoruba',
  'za' => 'Zhuang',
  'zh' => 'Cinese',
  'zu' => 'Zulu',
);
